@@ -21,12 +21,12 @@
 **  only under the terms of either the Artistic License or the GNU General
 **  Public License, which may be found in the ePerl source distribution.
 **  Look at the files ARTISTIC and COPYING or run ``eperl -l'' to receive
-**  a builtin copy of both license files.
+**  a built-in copy of both license files.
 **
 **  This program is distributed in the hope that it will be useful, but
 **  WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
-**  GNU General Public License or the Artistic License for more details.
+**  Artistic License or the GNU General Public License for more details.
 **
 **  ======================================================================
 **
@@ -83,6 +83,15 @@
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
+#ifdef HAVE_SYS_SOCKET_H
+#include <sys/socket.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+#ifdef HAVE_NETDB_H
+#include <netdb.h>
+#endif
 
 #ifdef SUNOS_LIB_PROTOTYPES
 /* Prototypes needed to get a clean compile with gcc -Wall.
@@ -150,7 +159,6 @@ char *vsprintf (char *, char *, va_list);
 #endif
 #endif
 
-
 /*
 **
 **  OS Return Values
@@ -175,7 +183,7 @@ char *vsprintf (char *, char *, va_list);
 #define EX_CONFIG       78      /* configuration error */
 #define EX__MAX         78      /* maximum listed value */
 
-/* OK and FAIL exits should ALLWAYS exists */
+/* OK and FAIL exits should ALWAYS exists */
 #ifndef EX_OK
 #define EX_OK   0
 #endif
@@ -270,20 +278,6 @@ char *vsprintf (char *, char *, va_list);
 #define FALSE (!(TRUE))
 /* typedef enum { false = FALSE, true = TRUE } bool; */
 
-/*   some other names for true and false */
-
-#define YES   TRUE
-#define NO    FALSE
-
-#define GOOD  TRUE
-#define WRONG FALSE
-
-#undef  OK
-#define OK    TRUE
-#define BAD   FALSE
-
-#define SOME  TRUE
-#define NONE  FALSE
 
 
 /*
